| Title: | Historical Brain Atlases for the 'ggseg' Ecosystem |
|---|---|
| Description: | Six historical cortical brain atlases digitally reconstructed by Pijnenburg et al. (2021) <doi:10.1016/j.neuroimage.2021.118274> from the Dutch Connectome Lab. Includes Brodmann (1909), Campbell (1905), Economo & Koskinas (1925), Flechsig (1920), Kleist (1934), and Smith (1907). Each atlas provides a unified 'ggseg_atlas' object with both 2D polygon geometry and 3D vertex indices, for use with 'ggseg' and 'ggseg3d'. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | CC BY-NC-SA 4.0 |
| Version: | 1.0.0 |
| Built: | 2026-05-23 09:06:23 UTC |
| Source: | https://github.com/ggsegverse/ggsegHistorical |
Brain atlas for the Brodmann areas cortical parcellation
with 39 regions per hemisphere. Contains both 2D polygon
geometry for ggseg::geom_brain() and 3D vertex indices
for ggseg3d::ggseg3d().
brodmann()brodmann()
A ggseg.formats::ggseg_atlas object (cortical).
Brodmann K (1909). Vergleichende Lokalisationslehre der Grosshirnrinde. Leipzig: Johann Ambrosius Barth.
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
campbell(),
economo(),
flechsig(),
kleist(),
smith()
Other cortical_atlases:
campbell(),
economo(),
flechsig(),
kleist(),
smith()
Other historical_atlases:
campbell(),
economo(),
flechsig(),
kleist(),
smith()
brodmann() plot(brodmann())brodmann() plot(brodmann())
Brain atlas for the Campbell (1905) cortical parcellation
with 17 regions per hemisphere. Contains both 2D polygon
geometry for ggseg::geom_brain() and 3D vertex indices
for ggseg3d::ggseg3d().
campbell()campbell()
A ggseg.formats::ggseg_atlas object (cortical).
Campbell A.W. (1905). Histological studies on the localisation of cerebral function. Cambridge University Press.
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
brodmann(),
economo(),
flechsig(),
kleist(),
smith()
Other cortical_atlases:
brodmann(),
economo(),
flechsig(),
kleist(),
smith()
Other historical_atlases:
brodmann(),
economo(),
flechsig(),
kleist(),
smith()
campbell() plot(campbell())campbell() plot(campbell())
Brain atlas based on the historical Economo & Koskinas 1925
cytoarchitectonic parcellation with 15 regions per
hemisphere. Contains both 2D polygon geometry for
ggseg::geom_brain() and 3D vertex indices for
ggseg3d::ggseg3d().
economo()economo()
A ggseg.formats::ggseg_atlas object (cortical).
C.F. von Economo, G.N. Koskinas; Die Cytoarchitektonik Der Hirnrinde Des Erwachsenen Menschen; J. Springer (1925)
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
brodmann(),
campbell(),
flechsig(),
kleist(),
smith()
Other cortical_atlases:
brodmann(),
campbell(),
flechsig(),
kleist(),
smith()
Other historical_atlases:
brodmann(),
campbell(),
flechsig(),
kleist(),
smith()
economo() plot(economo())economo() plot(economo())
Brain atlas for the Flechsig myelogenetic cortical
parcellation with 46 regions per hemisphere. Contains both
2D polygon geometry for ggseg::geom_brain() and 3D vertex
indices for ggseg3d::ggseg3d().
flechsig()flechsig()
A ggseg.formats::ggseg_atlas object (cortical).
Flechsig P (1920). Anatomie des menschlichen Gehirns und Ruckenmarks auf myelogenetischer Grundlage. Leipzig: Georg Thieme.
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
brodmann(),
campbell(),
economo(),
kleist(),
smith()
Other cortical_atlases:
brodmann(),
campbell(),
economo(),
kleist(),
smith()
Other historical_atlases:
brodmann(),
campbell(),
economo(),
kleist(),
smith()
flechsig() plot(flechsig())flechsig() plot(flechsig())
Brain atlas for the historical Kleist 1934 functional
segregation with 49 regions per hemisphere. Contains both
2D polygon geometry for ggseg::geom_brain() and 3D vertex
indices for ggseg3d::ggseg3d().
kleist()kleist()
A ggseg.formats::ggseg_atlas object (cortical).
Kleist K. (1934) Gehirnpathologie vornehmlich auf Grund der Kriegserfahrungen. Leipzig: Barth.
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
smith()
Other cortical_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
smith()
Other historical_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
smith()
kleist() plot(kleist())kleist() plot(kleist())
Brain atlas for the Smith 1907 cortical parcellation.
Contains both 2D polygon geometry for ggseg::geom_brain()
and 3D vertex indices for ggseg3d::ggseg3d().
smith()smith()
A ggseg.formats::ggseg_atlas object (cortical).
G.E. Smith; A new topographical survey of the human cerebral cortex, being an account of the distribution of the anatomically distinct cortical areas and their relationship to the cerebral sulci; J. Anat. Physiol., 41 (Pt 4) (1907), p. 237
Pijnenburg R, et al. (2021). Myelo- and cytoarchitectonic microstructural and functional human cortical atlases reconstructed in common MRI space. NeuroImage, 239, 118274. doi:10.1016/j.neuroimage.2021.118274
Other ggseg_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
kleist()
Other cortical_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
kleist()
Other historical_atlases:
brodmann(),
campbell(),
economo(),
flechsig(),
kleist()
smith() plot(smith())smith() plot(smith())